@@ -4,7 +4,9 @@
 #include <libhildondesktop/libhildondesktop.h>
 #include <gtk/gtk.h>
 
-void query_dialog_show(HDHomePluginItem *hdhpi, GtkTreeModel *tm);
+typedef void (*ShowSettingsDialogCb)(HDHomePluginItem *, GtkWindow *);
+
+void query_dialog_show(HDHomePluginItem *hdhpi, GtkTreeModel *tm, ShowSettingsDialogCb ssdcb);
 GtkWidget *query_dialog_make_tv(GtkTreeModel *tm, GtkWidget **p_tv);
 
 #endif /* !_QUERY_DIALOG_H_ */
